==> rialto-1.3.1-py3-none-any.whl: rialto/loader/interfaces.py <==
#  Copyright 2022 ABSA Group Limited
#
#  Licensed under the Apache License, Version 2.0 (the "License");
#  you may not use this file except in compliance with the License.
#  You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
#  Unless required by applicable law or agreed to in writing, software
#  distributed under the License is distributed on an "AS IS" BASIS,
#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#  See the License for the specific language governing permissions and
#  limitations under the License.

__all__ = ["DataLoader", "FeatureLoaderInterface"]

import abc
from datetime import date
from typing import Dict


class DataLoader(metaclass=abc.ABCMeta):
    """
    An interface to read feature groups from storage

    Requires read_group function.
    """

    @abc.abstractmethod
    def read_group(self, group: str, information_date: date):
        """
        Read one feature group

        :param group: Group name
        :param information_date: date
        """
        raise NotImplementedError


class FeatureLoaderInterface(metaclass=abc.ABCMeta):
    """
    A definition of feature loading interface

    Provides functionality to read features, feature groups and selections of features according to configs.
    Also provides an interface to access metadata of said features.
    """

    @abc.abstractmethod
    def get_feature(self, group_name: str, feature_name: str, information_date: date):
        """Get single feature"""
        raise NotImplementedError

    @abc.abstractmethod
    def get_feature_metadata(self, group_name: str, feature_name: str) -> Dict:
        """Get single feature's metadata"""
        raise NotImplementedError

    @abc.abstractmethod
    def get_group(self, group_name: str, information_date: date):
        """Get feature group"""
        raise NotImplementedError

    @abc.abstractmethod
    def get_group_metadata(self, group_name: str) -> Dict:
        """Get feature group's metadata"""
        raise NotImplementedError

    @abc.abstractmethod
    def get_features_from_cfg(self, path: str, information_date: date):
        """Get features from multiple groups as defined by configuration"""
        raise NotImplementedError

    @abc.abstractmethod
    def get_metadata_from_cfg(self, path: str) -> Dict:
        """Get metadata from multiple groups as defined by configuration"""
        raise NotImplementedError

==> rialto-2.0.2-py3-none-any.whl: rialto/loader/interfaces.py <==
#  Copyright 2022 ABSA Group Limited
#
#  Licensed under the Apache License, Version 2.0 (the "License");
#  you may not use this file except in compliance with the License.
#  You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
#  Unless required by applicable law or agreed to in writing, software
#  distributed under the License is distributed on an "AS IS" BASIS,
#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#  See the License for the specific language governing permissions and
#  limitations under the License.

__all__ = ["FeatureLoaderInterface"]

import abc
from datetime import date
from typing import Dict


class FeatureLoaderInterface(metaclass=abc.ABCMeta):
    """
    A definition of feature loading interface

    Provides functionality to read features, feature groups and selections of features according to configs.
    Also provides an interface to access metadata of said features.
    """

    @abc.abstractmethod
    def get_feature(self, group_name: str, feature_name: str, information_date: date):
        """Get single feature"""
        raise NotImplementedError

    @abc.abstractmethod
    def get_feature_metadata(self, group_name: str, feature_name: str) -> Dict:
        """Get single feature's metadata"""
        raise NotImplementedError

    @abc.abstractmethod
    def get_group(self, group_name: str, information_date: date):
        """Get feature group"""
        raise NotImplementedError

    @abc.abstractmethod
    def get_group_metadata(self, group_name: str) -> Dict:
        """Get feature group's metadata"""
        raise NotImplementedError

    @abc.abstractmethod
    def get_features_from_cfg(self, path: str, information_date: date):
        """Get features from multiple groups as defined by configuration"""
        raise NotImplementedError

    @abc.abstractmethod
    def get_metadata_from_cfg(self, path: str) -> Dict:
        """Get metadata from multiple groups as defined by configuration"""
        raise NotImplementedError
